package com.rf.psychological.mp.utils;


import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestTemplate;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

/**
 * @Author:zzf
 * @Date:2024/7/17:19:24
 * @Description: mp 工具类
 */
@Component
@Slf4j
public class MpUtils {


    @Value("${weixin.mpAppid}")
    private String mpAppid;

    @Value("${weixin.mpSecret}")
    private String mpSecret;

    @Value("${weixin.domain}")
    private String domain;

    @Value("${weixin.accessToken}")
    private String accessTokenUrl;

    @Value("${weixin.mpCode2AccessToken}")
    private String mpCode2AccessTokenUrl;

    @Value("${weixin.mpJsapiTicket}")
    private String mpJsapiTicketUrl;

    @Autowired
    private RestTemplate restTemplate;

    @Autowired
    private RedisTemplate<String,String> redisTemplate;





    /**
     *获取加密签名
     * @param token
     * @param timestamp
     * @param nonce
     * @return
     */
    public  String getSignature(String token, String timestamp, String nonce){
        List<String> list = Arrays.asList(token, timestamp, nonce);
        Collections.sort(list);
        StringBuilder stringBuilder = new StringBuilder();
        list.forEach(stringBuilder::append);
        MessageDigest instance;
        try {
            instance = MessageDigest.getInstance("sha1");
            byte[] digest = instance.digest(stringBuilder.toString().getBytes());
            StringBuilder sum = new StringBuilder();
            for (byte b : digest) {
                sum.append(Integer.toHexString((b>>4)&15));
                sum.append(Integer.toHexString(b&15));
            }
            return sum.toString();
        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException(e);
        }
    }


    /**
     * code 获取 accesstoken
     * @param code
     * @return
     */
    public JSONObject code2accesstoken(String code) {
        String requestUrl = domain +String.format(mpCode2AccessTokenUrl, mpAppid, mpSecret,code);
        ResponseEntity<String> response = restTemplate.getForEntity(requestUrl, String.class);
        JSONObject jsonObject = JSONObject.parseObject(response.getBody());
        if (!jsonObject.containsKey("errcode")){
            redisTemplate.opsForValue().set("access_token", jsonObject.getString("access_token"));
            return jsonObject;
        }else {
            log.error("code2accessToken 异常：");
            log.error("errcode:"+jsonObject.getString("errcode"));
            log.error("errmsg:"+jsonObject.getString("errmsg"));
        }
        return null;
    }

    /**
     * 获取web access_token
     * @return
     */
    public void getMpAccessToken(){
        try {
            log.info("获取accessToken");
            String requestUrl = domain+String.format(accessTokenUrl, mpAppid, mpSecret);
            // 发起GET请求获取凭证
            log.info(requestUrl);
            ResponseEntity<String> response = restTemplate.getForEntity(requestUrl, String.class);
            JSONObject jsonObject = JSONObject.parseObject(response.getBody());
            if(!jsonObject.containsKey("errcode")){
                redisTemplate.opsForValue().set("access_token",jsonObject.getString("access_token"));
            }else {
                log.error("获取accessToken异常：");
                log.error("errcode:"+jsonObject.getString("errcode"));
                log.error("errmsg:"+jsonObject.getString("errmsg"));
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error(e.getMessage());
        }

    }

    /**
     * 获取jsapi_ticket
     * @return
     */
    public void getMpJsapiTicket(){
        try {
            log.info("获取jsapi_ticket");
            String mpWebAccessToken = redisTemplate.opsForValue().get("access_token");
            if(StringUtils.isNotEmpty(mpWebAccessToken)){
                String requestUrl = domain +String.format(mpJsapiTicketUrl,mpWebAccessToken);
                ResponseEntity<String> response = restTemplate.getForEntity(requestUrl, String.class);
                JSONObject jsonObject = JSONObject.parseObject(response.getBody());
                if(jsonObject.getIntValue("errcode") == 0){
                    redisTemplate.opsForValue().set("jsapi_ticket",jsonObject.getString("ticket"));
                }else {
                    log.error("获取jsapi_ticket异常：");
                    log.error("errcode:"+jsonObject.getString("errcode"));
                    log.error("errmsg:"+jsonObject.getString("errmsg"));
                }
            }else{
                log.error("access_token 为空，将不再获取jsapi_ticket");
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error(e.getMessage());
        }


    }
}
