package com.rf.psychological.scale.resultBusiness.cognitiveResult;

import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.rf.psychological.dao.model.ObjectEntity;
import com.rf.psychological.file.excel.ExcelClass;
import com.rf.psychological.scale.resultBusiness.scaleResult.BaseScale;
import com.rf.psychological.user.dao.model.UserEntity;
import com.rf.psychological.utils.AgeUtil;
import com.rf.psychological.utils.Constant;
import com.rf.psychological.utils.ExcelUtil;
import com.rf.psychological.utils.RandomSuggestionUtil;
import org.apache.commons.lang.StringUtils;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

/**
 * @author zsy
 * @description:瑞文测试
 * @date 2021/7/20 15:55
 */
public class RIVENCognize extends BaseScale {

    public RIVENCognize(JSONArray jsonArray, JSONObject resultJson) {
        super(jsonArray, resultJson);
    }

    //总分五个等级，总分共五个等级：优秀、良好、中等、中下和低下
    private final static  String total1 = "1. 您拥有极高的逻辑推理能力和问题解决技巧。您能够迅速识别复杂图案中的规律，并有效地应用这些规律解决新问题。这种高水平的智力潜能使您在学术、职业及日常生活中都能展现出卓越的表现和创新思维。#;\n" +
            "2. 您展现出卓越的思维敏锐度和洞察力。您具备识别复杂模式的天赋，能够轻松把握其中的规律，并灵活地将这些规律应用到新的情境中。这种智力优势为您带来了广阔的发展潜力，使您在面对挑战时游刃有余，在学术、工作和生活中不断突破自我、展现创意。#;\n" +
            "3. 您展现出非凡的抽象思维和灵活应变的能力。您能够在错综复杂的信息网络中迅速识别核心规律，并将其巧妙地运用于新问题。这种智力优势不仅体现了您的高效学习能力，也表明您在处理复杂任务时拥有独到的见解与创新潜力，让您在各类情境中游刃有余。";
    private final static  String total2 = "1. 您在逻辑推理和问题解决方面具有较强的能力。您能够较好地理解和分析复杂信息，运用逻辑推断来找出解决方案。这一结果预示着您在多数智力挑战中都能表现出色，适合从事需要一定智力水平和分析能力的工作或学习任务。#;\n" +
            "2. 您在逻辑推理和问题解决方面的可靠能力。您能够较为敏锐地捕捉和分析复杂信息，利用清晰的逻辑来制定解决方案。这个结果表明，您在大多数需要思维深度的挑战中都能应对自如，适合参与需要思维条理性和洞察力的工作或项目。#;\n" +
            "3. 您在逻辑推理和问题解决方面具备良好的基础，能够有效地分析复杂信息，并通过逻辑思维找到合适的解决方法。这样的能力预示着您在各种需要思维严谨和判断力的任务中都能够胜任，能够在需要分析力和智力支持的工作或项目取得一定的成功。";
    private final static  String total3 = "1. 您具备基本的逻辑推理和问题解决技能。您能够处理日常生活中的大多数智力需求，但在面对高度复杂或抽象的问题时可能需要更多时间和努力。通过持续学习和练习，您有望进一步提升自己的逻辑推理和问题解决能力，拓宽解决问题的能力范围。#;\n" +
            "2. 您在逻辑推理和问题解决方面具有扎实的基础，能够胜任日常生活中的大部分智力任务。面对更复杂或抽象的问题时，您可能需要投入额外的时间和努力。随着持续的学习和练习，您有望不断提升思维能力，进一步拓展自己的问题解决技能。#;\n" +
            "3. 您具备基本的逻辑推理和解决问题的能力。在处理日常生活中的一般智力任务时，您表现得较为稳健，但在应对高度复杂或抽象问题时可能需要投入更多的时间和精力。通过不断的学习和实践，您可以进一步提升自己的思维能力，从而拓展自身的解决问题能力。";
    private final static  String total4 = "1. 您在逻辑推理和问题解决方面目前处于较为基础的水平，这意味着您在面对高度复杂或抽象的问题时可能需要额外的支持和指导。通过参加针对性的训练课程、寻求专业辅导或参与更多智力刺激活动，您可以逐步增强自己的逻辑思考能力和问题解决技巧。#;\n" +
            "2. 您在逻辑推理和问题解决方面目前处于较为基础的水平，面对极具挑战性或深度抽象的问题时，或许会感到需要更多的协助与引领。参与定制化的培训课程、寻找专家指导或投身于更多激发思维的活动，将是您逐步提升逻辑敏锐度与问题解决本领的有效途径。#;\n" +
            "3. 您在逻辑推理和问题解决方面的能力目前处于基础阶段，这为您提供了进一步发展的空间。在面对智力挑战时，您可能会从额外的支持和指导中获益。通过参加专门的训练、接受专业的辅导，或多参与能激发思维的活动，您有机会逐步提升逻辑思考和问题解决的技能。";
    private final static  String total5 = "1. 在逻辑推理和问题解决方面，您目前正处于一个充满成长潜力的起点，这表明您在逻辑推理和问题解决方面有着巨大的提升空间。通过采用专门定制的教学方法、获得更多个性化的辅导，或是积极寻找适合您的学习资源，可以有效地满足自己的学习需求。保持那份积极向上的心态至关重要，运用适合自己的学习策略，一步步地迎接挑战，您将惊喜地发现，自己在不断挖掘并最大化地实现着个人潜能。\n" +
            "2. 在理解与解决问题的领域，您目前正站在一个潜力无限的起跑线上，这预示着您在逻辑思维与问题解决能力上有着广阔的进步空间。借助量身定制的学习方案、寻求个性化的指导，或是主动探索符合您学习节奏的资源，您将能够高效地满足自己的求知渴望。保持一颗勇于探索的心，运用恰当的学习策略，一步步攀登挑战的高峰，您会发现，自己在不断地解锁并发挥着前所未有的个人潜能。#;\n" +
            "3. 面对逻辑思考与解决问题的挑战，您此刻正处在一个蕴含无限可能的起点，这显示出您在逻辑推理与问题解决领域拥有着巨大的成长余地。通过采纳为您独家设计的教学途径、接受针对性的辅导，或是积极寻觅贴合您学习习惯的资源，您将能够有效地填补知识的空缺。保持那份积极进取的心态，运用适合自己的学习策略，一步步跨越障碍，您将会惊喜地见证，自己在不断地挖掘并展现着个人潜能的无限深度。";

    //维度一
    private final static String A1 = "1. 您在处理外界环境信息时，具备出色的组织和整合能力，能够快速将不同来源的感觉信息统筹起来，形成完整的认知视图。这种全局观使您在看待问题时不易被细节干扰，反而能从整体出发，综合分析各方面因素。您的观察力敏锐，能在复杂的环境中耳听八方、眼观六路，准确把握关键点并做出合理判断，从而更有效地应对各种情境和挑战。#;\n" +
            "2. 您在处理外界信息时具备很强的组织和整合能力，能够迅速将不同感官渠道的输入统一起来，形成清晰的整体认识。您的全局视角使您在分析问题时能抓住关键，不被局部细节所困，反而能从宏观层面综合评估各方面的影响。您观察敏锐，能在复杂环境中迅速捕捉到重要信息，耳听八方、眼观六路，使您能够从容应对多种情境并作出明智判断。#;\n" +
            "3. 您具备卓越的感官信息整合能力，能够迅速将多方位的感知融合成整体的认知视角。这种全局观帮助您在分析问题时保持重点清晰，不受细节的干扰，更多地从宏观层面审视各种因素。您的敏锐观察力使您能够在复杂的情境中迅速抓住关键信息，真正做到耳听八方、眼观六路，从而有效应对多样的环境和挑战。";
    private final static String A2 = "1. 您在整合外界环境中来自不同感官的信息时可能存在一定困难，这使得您在分析和处理问题时容易忽略对整体情况的把握。在面对复杂的情境时，您可能会更多地关注细节，而不自觉地忽视了更广泛的背景或关键因素，从而导致决策上可能出现偏差或处理不当。这种局限性可能影响您在多任务处理或需要全局观的情况下的表现。#;\n" +
            "2. 您在处理外界环境中的多重感官信息时可能存在一些挑战，这在分析问题时可能导致对整体情况缺乏全面的掌控。面对复杂情境时，您可能更容易被具体细节吸引，而忽视了更大的背景或关键环节，从而在决策过程中出现一定的偏差。这种情况可能在多任务处理或需要整体视角的场合中影响您的表现。#;\n" +
            "3. 您在整合外界环境中的各种感官信息时可能遇到一些困难，这使得您在处理问题时容易忽视整体的把控或出现偏差。在面对复杂或多变的情况时，您可能更多关注局部细节，而忽略了整体框架，从而影响了决策的准确性或处理的有效性。这种情况可能会在需要全局视角的任务中限制您的表现。";
    //维度二
    private final static String B1 = "1. 您在识别同类现象并洞察其共同规律方面展现出了卓越的能力，能够迅速捕捉事物之间的微妙联系与相似性，进而进行精准而高效的归纳总结。这种能力让您在面对纷繁复杂的信息海洋时，您能够迅速筛选出那些真正有价值的核心要素，排除干扰，直达问题的本质。因此，您不仅能够形成条理清晰、逻辑严密的结论，还能深刻理解这些结论背后的深层次含义，展现出一种超越常人的智慧与洞见。#;\n" +
            "2. 您在探索同类现象并提炼其共通法则的过程中表现出非凡的敏锐与深刻的智慧。您擅长于迅速洞察事物间的内在联系与相似性，并以此为基础，进行条理清晰、逻辑缜密的归纳总结。面对海量的复杂信息，您能够精准地辨识出关键信息，抽丝剥茧，直达核心。这不仅使您能够迅速形成见解独到、条理清晰的结论，更能让您深刻理解这些结论背后的逻辑脉络与深层意义，展现出一种令人瞩目的智慧与洞察力。#;\n" +
            "3. 您在识别同类现象并把握其共同规律方面，展现出了令人赞叹的敏锐与智慧。您能够迅速捕捉事物间的微妙关联与相似性，进行细致入微的归纳与总结。在应对复杂多变的信息挑战时，您能够准确提炼出关键要素，构建出清晰明了的理解框架。这不仅让您能够迅速形成条理清晰、逻辑严密的结论，更使您能够深入剖析这些结论背后的深层次逻辑与关联，展现出一种超凡脱俗的智慧与洞见。";
    private final static String B2 = "1. 在类同比较的过程中，您可能会遇到一些挑战，难以迅速察觉到信息之间的内在联系，掌握这一能力或许需要您付出更多的时间与精力。不过这并不代表无法克服，您可以在学习和训练中着重加强类同比较的能力培养。通过一系列有针对性的练习，您将能够提升自己在纷繁复杂的现象或信息中敏锐识别共性与差异的能力，进而更加高效地归纳总结，使您的思考更加条理清晰，逻辑严密。#;\n" +
            "2. 您在尝试通过类同比较来发现规律和进行归纳总结时，可能会感到一定的难度，难以迅速把握信息间的相似性和关联性，这需要您投入更多的耐心与努力来逐步掌握这项技能。建议您在未来的学习与实践中，特别关注并强化类同比较能力的锻炼。通过一系列精心设计的练习，您将逐渐增强自己在不同情境下识别共性与差异的能力，使您在归纳总结时能够更加得心应手，思维更加敏锐与全面。#;\n" +
            "3. 面对利用类同比较能力来提炼规律和归纳总结的任务，您可能会遇到一些阻碍，难以迅速洞察信息之间的内在联系，这要求您付出更多的时间和心力来培养这一能力。建议您可以专注于提升类同比较的能力，通过一系列富有挑战性的练习，您将能够增强自己在复杂信息中辨识共性与个性特征的能力，从而更有效地进行归纳总结。这不仅会让您的思考更加深入与细致，也会为您的学习和工作带来显著的助益。";
    //维度三
    private final static String C1 = "1. 您具备出色的举一反三能力，能够迅速将已学知识和经验迁移到新的情境中，并在不同的领域中灵活应用。这种强大的迁移学习能力使得您不仅能够更高效地吸收新信息，还能在面对复杂问题时，快速找到解决方案并加以实施。随着这种能力的不断提升，您将能够在多种情境中展现出更高的创造力，提出独特的见解和创新的解决办法。因此，您的思维方式将越来越具有突破性和前瞻性，在解决问题和开展创意工作时，展现出更强的竞争力。#;\n" +
            "2. 您在举一反三和迁移学习方面具有卓越的能力，能够轻松将已有的知识和经验应用到新的情境中，并通过灵活的思维方式解决不同类型的问题。这种能力让您不仅能够快速掌握新信息，还能够在面对新的挑战时迅速找到关联并有效应用。随着这一能力的不断发展，您将能够发挥出更强的创造力，产生更多独特的想法和创新方案。这使得您在多变的环境中能够持续提供新颖的解决方案，展现出独特的思维优势。#;\n" +
            "3. 您具备卓越的举一反三能力，能够将已有的知识和经验迅速转化并运用到新的情境中。这种迁移学习的优势使得您在面对新问题时，能够灵活地借鉴过去的解决方案，并快速找到合适的应对策略。随着这种能力的进一步发展，您将能够激发更强的创造力，提出独特且创新的想法。这不仅增强了您解决问题的能力，还为您在不断变化的环境中提供了持续的创新动力。";
    private final static String C2 = "1. 您的举一反三能力目前尚处于成长阶段，这意味着在面对新颖问题时，您可能需要一些时间来适应，将既有知识巧妙地应用于不同情境。同时，您在迁移学习与解决问题的技巧上也拥有不小的提升空间，这可能导致在遭遇陌生挑战时，您需要花费更多精力去摸索。然而，通过专门的训练与持续实践，您将能够稳步增进这些能力，使自己在多变的环境中更加游刃有余，展现出灵活应对与创新解决问题的卓越才能。#;\n" +
            "2. 这意味着，当面对陌生问题时，您可能需要更多时间去探索和适应。同时，在迁移学习和解决问题的策略上，您也有着相当大的进步空间，这可能导致您在解决新问题时需要投入更多精力。但请相信，通过有针对性的练习和不断的实践，您将能够显著提升这些能力，让自己在多变的环境中更加自如，展现出出色的适应性和创新解决问题的能力。#;\n" +
            "3. 您在运用已有知识解决新问题上，正处于一个逐步构建与提升的过程中。面对新情境时，您可能需要额外的时间来调整和适应，将所学知识融入到新的环境中。此外，在迁移学习技巧及独立解决问题方面，您也具备很大的成长潜力，尽管这可能在面对未知挑战时增加了一些探索的难度。然而，通过系统性的训练与反复的实践，您将能够循序渐进地增强这些能力，使自己在复杂多变的环境中更加灵活多变，展现出卓越的问题解决与创新思维。";
    //维度四
    private final static String D1 = "1. 您具备较强的场景动态敏感性，能够迅速察觉周围环境和情境的变化。这使您在换位思考时更具同理心，能够站在他人的角度理解和感受他们的情绪和需求。您的交际能力也非常出色，能够通过细致的观察和有效的沟通与他人建立良好的关系。这种敏感度和同理心让您在与人互动时，更能把握对方的心理状态，促进理解和合作。#;\n" +
            "2. 您对环境变化具有较高的敏感性，能够快速察觉场景中的动态变化。这使得您在与他人互动时，能够更好地进行换位思考，从而理解他人的感受和需求。您的交际能力也非常出色，能够通过细腻的观察和有效的沟通建立起深层次的联系。您能够体会他人的内心世界，这让您在人际交往中更容易获得信任和合作。#;\n" +
            "3. 您在察觉场景变化和动态方面具有较强的敏感度，能够快速适应不同的环境和情境。在与他人交往时，您能够有效地换位思考，理解他人的情感和立场，从而建立更加深入的连接。您的交际技巧十分出色，能够通过细致的观察和沟通与他人建立信任，这使您更加擅长感知并体会他人内心的真实想法和需求。";
    private final static String D2 = "1. 您可能较难进行换位思考，更倾向于专注于自己的内心世界，而较少关注他人的情感和需求。尽管如此，这种独立的思维方式让您在思考问题时能够更深入，展现出较强的分析能力和内在的思维深度。您能够从自己的视角深刻理解复杂问题，培养出独特且有深度的思维方式。#;\n" +
            "2. 您可能较难进行换位思考，更倾向于活在自己的思维世界中，这让您在理解他人情感和需求时可能会遇到一定挑战。然而，从另一个角度来看，这种独立思考的特质使得您在深入思考和分析问题时展现出更强的思维能力。您能够集中精力在自己的内心世界中探索复杂的想法，从而培养出深邃的洞察力和独特的思维方式。#;\n" +
            "3. 您可能不太习惯从他人的角度看问题，更倾向于沉浸在自己的思维和感受中。这种倾向可能导致您在理解他人情感时稍显困难。然而，从另一个角度来看，这种独立的思维方式使得您拥有更加深邃的内心世界和强大的思维能力，能够深入探索复杂的思想和问题，发展出独特的视角和洞察力。";
    //维度五
    private final static String E1 = "1. 您具备世俗意义上的高智商，思维灵活，能够迅速适应各种认知挑战。您的创造力和想象力也非常出色，能够提出独特的见解并突破常规思维。这些特点使您在科学研究和发明创造等领域表现出色，能够不断推动创新，解决复杂的问题。您善于从不同角度看待问题，具备探索未知的潜力，适合从事需要高度智力和创新思维的工作，如科学家或发明家。#;\n" +
            "2. 您拥有高智商，思维极为灵活，能够迅速适应复杂的认知任务。您的创造力和想象力非常突出，能够跳出常规框架，提出新的解决方案。这些优势使您非常适合从事科学研究或发明创造等工作，能够在探索未知领域时发挥巨大的潜力。您的能力让您能够不断推动创新，解决各种复杂问题，适合进入那些需要高度智力和创新思维的职业领域。#;\n" +
            "3. 您具备出众的智力和高度灵活的思维方式，能够轻松应对各种认知挑战。您的创造力和想象力丰富，常能提出独到的见解和创新的解决方案。这些特质使您非常适合从事科学研究或发明创造等需要高度智力和创新的职业。您能够在复杂问题面前发挥独特的思维优势，不断推动技术和理念的创新，为解决世界难题做出贡献。";
    private final static String E2 = "1. 在抽象推理领域，您可能还在寻找最适合自己的理解路径。这可能会让您在面对错综复杂的逻辑关系和抽象问题时，感到一定的挑战。但请放心，通过精心设计的练习与持续的学习，您完全有能力逐步增强这些能力，深化对抽象概念的认识，为将来攻克复杂难题奠定更为坚实的基石。#;\n" +
            "2. 在处理抽象推理任务时，您可能还在探索最适合自己的思维方式。这可能导致在面对复杂逻辑和抽象概念时，您会遭遇一些理解上的障碍。但请不要担心，通过坚持不懈的针对性练习和深入学习，您将能够逐步克服这些挑战，深化对抽象事物的理解，能够为日后解决复杂问题铺设一条更为宽广的道路。#;\n" +
            "3. 在抽象推理方面，您可能还在寻找那把打开理解之门的钥匙。这意味着，在面对需要深度逻辑分析和抽象思考的挑战时，您可能会遇到一些困难。然而，通过持续不断的努力、有针对性的练习以及深入的学习，您将能够逐步提升自己的能力，更加深入地把握抽象概念，为将来在复杂问题上的突破打下坚实的基础。";


    public  JSONObject scaleCalculate() throws Exception {
        List<Map<String, String>> resultMapList = new ArrayList<>();
        JSONObject jsonObject = resultJson.getJSONObject("jsonObject");
        String fileName = resultJson.getString("fileName") + "-" + Constant.SHEET_NAME_RIVEN + ".xlsx";
        UserEntity userEntity = (UserEntity) resultJson.get("userEntity");
        JSONArray jsonArray = jsonObject.getJSONArray("data");
        int score = jsonObject.getInteger("userScore");
        String name = Constant.SHEET_NAME_RIVEN;
        int resultScore = RIVENScore(userEntity.getBirthday(), score);

        JSONObject resultDBJson = new JSONObject(true);
        resultDBJson.put("versionNo", "2.0");
        //知觉辨别能力得分
        int A = 0;
        //类同比较能力得分
        int B = 0;
        //比较推理能力得分
        int C = 0;
        //系列关系能力得分
        int D = 0;
        //抽象推理能力得分
        int E = 0;
        for (int i = 0; i < jsonArray.size(); i++) {
            JSONObject jsonObject1 = jsonArray.getJSONObject(i);
            if (i <= 11){
                A += Integer.valueOf(jsonObject1.getInteger("score"));
            }else if (i >= 12 && i <= 23){
                B += Integer.valueOf(jsonObject1.getInteger("score"));
            }else if (i >= 24&& i <= 35){
                C += Integer.valueOf(jsonObject1.getInteger("score"));
            }else if (i >= 36 && i <= 47){
                D += Integer.valueOf(jsonObject1.getInteger("score"));
            }else {
                E += Integer.valueOf(jsonObject1.getInteger("score"));
            }
        }
        //总分模块
        JSONArray totalScores = new JSONArray();
        JSONObject totalScoreObject = new JSONObject(true);
        totalScoreObject.put("totalScore",score);
        if (resultScore < 5) {
            totalScoreObject.put("totalScoreDesc","智力水平低下");
            totalScoreObject.put("totalScoreUnscramble", RandomSuggestionUtil.getSuggestion(total5));
        } else if (resultScore >= 5 && resultScore <= 24) {
            totalScoreObject.put("totalScoreDesc","智力水平中下");
            totalScoreObject.put("totalScoreUnscramble", RandomSuggestionUtil.getSuggestion(total4));
        } else if (resultScore >= 25 && resultScore <= 74) {
            totalScoreObject.put("totalScoreDesc","智力水平中等");
            totalScoreObject.put("totalScoreUnscramble", RandomSuggestionUtil.getSuggestion(total3));
        } else if (resultScore >= 75 && resultScore <= 94) {
            totalScoreObject.put("totalScoreDesc","智力水平良好");
            totalScoreObject.put("totalScoreUnscramble", RandomSuggestionUtil.getSuggestion(total2));
        } else {
            totalScoreObject.put("totalScoreDesc","智力水平优秀");
            totalScoreObject.put("totalScoreUnscramble", RandomSuggestionUtil.getSuggestion(total1));
        }

        totalScores.add(totalScoreObject);
        resultDBJson.put("totalScore", totalScores);

        //表格数据
        JSONArray tableModule = new JSONArray();
        JSONObject table1 = new JSONObject(true);
        JSONArray columnName = new JSONArray();
        columnName.add("评估指标");
        columnName.add("我的");
        JSONArray columnValue = new JSONArray();
        columnValue.add("知觉辨别能力;类同比较能力;比较推理能力;系列关系能力;抽象推理能力");
        columnValue.add(A+";"+B+";"+C+";"+D+";"+E);
        table1.put("tableName","table1");
        table1.put("columnName",columnName);
        table1.put("columnValue",columnValue);
        tableModule.add(table1);
        resultDBJson.put("tableModule", tableModule);

        //图表模块
        JSONObject chartModule = new JSONObject(true);
        chartModule.put("chartType","radar");
        JSONObject chartBody = new JSONObject(true);
        JSONArray indicator = new JSONArray();
        JSONObject indicatorA = new JSONObject(true);
        indicatorA.put("name","知觉辨别能力");
        indicatorA.put("max",12);
        indicator.add(indicatorA);
        JSONObject indicatorB = new JSONObject(true);
        indicatorB.put("name","类同比较能力");
        indicatorB.put("max",12);
        indicator.add(indicatorB);
        JSONObject indicatorC = new JSONObject(true);
        indicatorC.put("name","比较推理能力");
        indicatorC.put("max",12);
        indicator.add(indicatorC);
        JSONObject indicatorD = new JSONObject(true);
        indicatorD.put("name","系列关系能力");
        indicatorD.put("max",12);
        indicator.add(indicatorD);
        JSONObject indicatorE = new JSONObject(true);
        indicatorE.put("name","抽象推理能力");
        indicatorE.put("max",12);
        indicator.add(indicatorE);
        chartBody.put("indicator",indicator);
        JSONArray groupData = new JSONArray();
        JSONObject group1 = new JSONObject(true);
        JSONArray group1Value = new JSONArray();
        group1Value.add(A);
        group1Value.add(B);
        group1Value.add(C);
        group1Value.add(D);
        group1Value.add(E);
        group1.put("index",1);
        group1.put("value",group1Value);
        group1.put("name","group1");
        groupData.add(group1);
        chartBody.put("groupData",groupData);
        chartModule.put("chartBody",chartBody);
        resultDBJson.put("chartModule", chartModule);

        //维度得分及结论模块
        JSONArray dimensions = new JSONArray();
        JSONObject scoreA = new JSONObject(true);
        scoreA.put("name","知觉辨别能力");
        scoreA.put("score",A);
        scoreA.put("Describe","知觉辨认能力是指对外界感官信息做出整体性辨别的能力，比如万花丛中一点绿，在视力水平相等情况下，知觉辨认能力强的人会马上察觉到这点绿，而知觉辨认能力弱的人则不能。");
        scoreA.put("conclusion",this.getConclusionByScore(A));
        scoreA.put("unscramble",this.getUnscrambleByScore(A,A1,A2));
        scoreA.put("Describe","知觉辨认能力是指对外界感官信息做出整体性辨别的能力，比如万花丛中一点绿，在视力水平相等情况下，知觉辨认能力强的人会马上察觉到这点绿，而知觉辨认能力弱的人则不能。");
        scoreA.put("maximum","12");
        scoreA.put("groupName","第一组");
        dimensions.add(scoreA);
        JSONObject scoreB = new JSONObject(true);
        scoreB.put("name","类同比较能力");
        scoreB.put("score",B);
        scoreB.put("Describe","类同比较能力跟比较推理能力差不多，不同的是类同比较能力只强调个体将同类事物进行比较并从中提取出共同要素即可，而不强调举一反三将其用于其他同类问题的解决。因此简单地说，类同比较能力就相当于找不同。");
        scoreB.put("conclusion",this.getConclusionByScore(B));
        scoreB.put("unscramble",this.getUnscrambleByScore(B,B1,B2));
        scoreB.put("maximum","12");
        scoreB.put("groupName","第一组");
        dimensions.add(scoreB);
        JSONObject scoreC = new JSONObject(true);
        scoreC.put("name","比较推理能力");
        scoreC.put("score",C);
        scoreC.put("Describe","比较推理能力是指个体从同类现象或问题中提取出共性因素，举一反三，并应用于其他同类问题的解决中去的能力，比如鲁班根据茅草发明了锯子，人类根据鸟的模型发明了飞机等。");
        scoreC.put("conclusion",this.getConclusionByScore(C));
        scoreC.put("unscramble",this.getUnscrambleByScore(C,C1,C2));
        scoreC.put("maximum","12");
        scoreC.put("groupName","第一组");
        dimensions.add(scoreC);
        JSONObject scoreD = new JSONObject(true);
        scoreD.put("name","系列关系能力");
        scoreD.put("score",D);
        scoreD.put("Describe","系列关系能力指个体对情景中若干信息之间的联系的觉察能力，该能力高的个体偏向场依存的认知模式，更能觉察到情景中的变化，更关注外界，该能力低的个体偏向场独立的认知模式，更关注内在。但需要注意的是，场依存和场独立的认知模式是中性的，无好坏之分，而系列关系能力作为一种认知能力是有高低好坏之分的，高肯定比低好。");
        scoreD.put("conclusion",this.getConclusionByScore(D));
        scoreD.put("unscramble",this.getUnscrambleByScore(D,D1,D2));
        scoreD.put("maximum","12");
        scoreD.put("groupName","第一组");
        dimensions.add(scoreD);
        JSONObject scoreE = new JSONObject(true);
        scoreE.put("name","抽象推理能力");
        scoreE.put("score",E);
        scoreE.put("Describe","抽象推理能力是一种高级思维能力，小孩在7岁左右开始萌芽，12岁左右青春期开始较快发展。抽象推理能力指不仅能把握事物的表面，更能揭露事物的深层本质，即透过现象看本质的能力。");
        scoreE.put("conclusion",this.getConclusionByScore(E));
        scoreE.put("unscramble",this.getUnscrambleByScore(E,D1,D2));
        scoreE.put("maximum","12");
        scoreE.put("groupName","第一组");
        dimensions.add(scoreE);
        resultDBJson.put("dimensions", dimensions);
        resultDBJson.put("note", "通过五个方面得分的结构，一定程度上有助于了解被测者智力结构。 \n" +
                "对分数作解释时注意，由于瑞文测验强调推理方面的能力，并非完全的智力，目前仅用于智力方面的筛选。因此不能绝对化。\n" +
                "该测验根据斯皮尔曼智力二因素理论编制，所测量的均为一般智力，而不是某方面的特殊技能。\n" +
                "本报告不具有临床诊断意义，仅供专业人员参考。\n" +
                "智力不是一成不变的，会随着年龄变化和受教育以及环境等因素变化而变化，所以以上维度智力得分低的受测者可以通专业训练提升。");
        //显示模块
        JSONObject ifShow = new JSONObject(true);
        ifShow.put("totalScore",true);
        ifShow.put("dimensions",true);
        ifShow.put("note",true);
        ifShow.put("radar",true);
        ifShow.put("table",true);
        resultDBJson.put("ifShow", ifShow);

        Map<String, String> resultMap = new LinkedHashMap<>();
        resultMap.put("知觉辨别能力", String.valueOf(A));
        resultDBJson.put("知觉辨别能力", String.valueOf(A));
        resultMap.put("类同比较能力", String.valueOf(B));
        resultDBJson.put("类同比较能力", String.valueOf(B));
        resultMap.put("比较推理能力", String.valueOf(C));
        resultDBJson.put("比较推理能力", String.valueOf(C));
        resultMap.put("系列关系能力", String.valueOf(D));
        resultDBJson.put("系列关系能力", String.valueOf(D));
        resultMap.put("抽象推理能力", String.valueOf(E));
        resultDBJson.put("抽象推理能力", String.valueOf(E));
        resultMapList.add(resultMap);

        String datas = jsonArray.toString();
        ExcelUtil.createExcelFile(ObjectEntity.class, jsonArray.toJavaList(ObjectEntity.class), resultMapList, new ExcelClass().contentExcel(Constant.QUEST_TYPE_RIVEN), fileName, Constant.SHEET_NAME_RIVEN);
        
        JSONObject returnJson = new JSONObject(true);
        returnJson.put("fileName",fileName);
        returnJson.put("name", name);
        returnJson.put("resultJson",resultDBJson);
        returnJson.put("datas",datas);

        return returnJson;
    }

    /**
     * 根据维度得分获取到维度解读
     * @param score 维度得分
     * @param unscramble1 较好
     * @param unscramble2 较差
     * @return
     */
    private String getUnscrambleByScore(int score,String unscramble1,String unscramble2){
        if ( score >= 0 &&  score <=6){
            return RandomSuggestionUtil.getSuggestion(unscramble2);
        }else {
            return RandomSuggestionUtil.getSuggestion(unscramble1);
        }
    }

    /**
     * 根据维度得分获取到维度结论
     * @param score 维度得分
     * @return
     */
    private String getConclusionByScore(int score){
        if ( score >= 0 &&  score <=6){
            return "较差";
        }else {
            return "较好";
        }
    }


    //瑞文根据年龄分值转换
    private int RIVENScore(String userBirthday, int score) throws Exception {
        int resultScore = 0;
        if (StringUtils.isEmpty(userBirthday) || "-".equals(userBirthday)){
            userBirthday = DateUtil.now();
        }
        double age = AgeUtil.getAge(userBirthday);
        if (age <= 5.5) {
            if (score >= 9 && score < 12) {
                resultScore = 5;
            } else if (score >= 12 && score < 13) {
                resultScore = 10;
            } else if (score >= 13 && score < 16) {
                resultScore = 25;
            } else if (score >= 16 && score < 25) {
                resultScore = 50;
            } else if (score >= 25 && score < 29) {
                resultScore = 75;
            } else if (score >= 29 && score < 34) {
                resultScore = 90;
            } else if (score >= 34) {
                resultScore = 95;
            }
        } else if (age == 6) {
            if (score >= 9 && score < 12) {
                resultScore = 5;
            } else if (score >= 12 && score < 13) {
                resultScore = 10;
            } else if (score >= 13 && score < 17) {
                resultScore = 25;
            } else if (score >= 17 && score < 25) {
                resultScore = 50;
            } else if (score >= 25 && score < 31) {
                resultScore = 75;
            } else if (score >= 31 && score < 36) {
                resultScore = 90;
            } else if (score >= 36) {
                resultScore = 95;
            }
        } else if (age == 6.5) {
            if (score >= 10 && score < 12) {
                resultScore = 5;
            } else if (score >= 12 && score < 13) {
                resultScore = 10;
            } else if (score >= 13 && score < 18) {
                resultScore = 25;
            } else if (score >= 18 && score < 25) {
                resultScore = 50;
            } else if (score >= 25 && score < 31) {
                resultScore = 75;
            } else if (score >= 31 && score < 37) {
                resultScore = 90;
            } else if (score >= 37) {
                resultScore = 95;
            }
        } else if (age == 7) {
            if (score >= 10 && score < 12) {
                resultScore = 5;
            } else if (score >= 12 && score < 13) {
                resultScore = 10;
            } else if (score >= 13 && score < 19) {
                resultScore = 25;
            } else if (score >= 19 && score < 25) {
                resultScore = 50;
            } else if (score >= 25 && score < 36) {
                resultScore = 75;
            } else if (score >= 36 && score < 43) {
                resultScore = 90;
            } else if (score >= 43) {
                resultScore = 95;
            }
        } else if (age == 7.5) {
            if (score >= 10 && score < 12) {
                resultScore = 5;
            } else if (score >= 12 && score < 13) {
                resultScore = 10;
            } else if (score >= 13 && score < 21) {
                resultScore = 25;
            } else if (score >= 21 && score < 31) {
                resultScore = 50;
            } else if (score >= 31 && score < 38) {
                resultScore = 75;
            } else if (score >= 38 && score < 44) {
                resultScore = 90;
            } else if (score >= 44) {
                resultScore = 95;
            }
        } else if (age == 8) {
            if (score >= 10 && score < 13) {
                resultScore = 5;
            } else if (score >= 13 && score < 15) {
                resultScore = 10;
            } else if (score >= 15 && score < 23) {
                resultScore = 25;
            } else if (score >= 23 && score < 31) {
                resultScore = 50;
            } else if (score >= 31 && score < 39) {
                resultScore = 75;
            } else if (score >= 39 && score < 44) {
                resultScore = 90;
            } else if (score >= 44) {
                resultScore = 95;
            }
        } else if (age == 8.5) {
            if (score >= 12 && score < 14) {
                resultScore = 5;
            } else if (score >= 14 && score < 20) {
                resultScore = 10;
            } else if (score >= 20 && score < 29) {
                resultScore = 25;
            } else if (score >= 29 && score < 33) {
                resultScore = 50;
            } else if (score >= 33 && score < 40) {
                resultScore = 75;
            } else if (score >= 40 && score < 45) {
                resultScore = 90;
            } else if (score >= 45) {
                resultScore = 95;
            }

        } else if (age == 9) {
            if (score >= 12 && score < 14) {
                resultScore = 5;
            } else if (score >= 14 && score < 25) {
                resultScore = 10;
            } else if (score >= 25 && score < 33) {
                resultScore = 25;
            } else if (score >= 33 && score < 37) {
                resultScore = 50;
            } else if (score >= 37 && score < 43) {
                resultScore = 75;
            } else if (score >= 43 && score < 47) {
                resultScore = 90;
            } else if (score >= 47) {
                resultScore = 95;
            }

        } else if (age == 9.5) {
            if (score >= 13 && score < 17) {
                resultScore = 5;
            } else if (score >= 17 && score < 27) {
                resultScore = 10;
            } else if (score >= 27 && score < 35) {
                resultScore = 25;
            } else if (score >= 35 && score < 39) {
                resultScore = 50;
            } else if (score >= 39 && score < 47) {
                resultScore = 75;
            } else if (score >= 47 && score < 50) {
                resultScore = 90;
            } else if (score >= 50) {
                resultScore = 95;
            }

        } else if (age == 10) {
            if (score >= 13 && score < 17) {
                resultScore = 5;
            } else if (score >= 17 && score < 27) {
                resultScore = 10;
            } else if (score >= 27 && score < 35) {
                resultScore = 25;
            } else if (score >= 35 && score < 42) {
                resultScore = 50;
            } else if (score >= 42 && score < 48) {
                resultScore = 75;
            } else if (score >= 48 && score < 50) {
                resultScore = 90;
            } else if (score >= 50) {
                resultScore = 95;
            }

        } else if (age == 10.5) {
            if (score >= 18 && score < 25) {
                resultScore = 5;
            } else if (score >= 25 && score < 32) {
                resultScore = 10;
            } else if (score >= 32 && score < 39) {
                resultScore = 25;
            } else if (score >= 39 && score < 42) {
                resultScore = 50;
            } else if (score >= 42 && score < 49) {
                resultScore = 75;
            } else if (score >= 49 && score < 50) {
                resultScore = 90;
            } else if (score >= 50) {
                resultScore = 95;
            }

        } else if (age == 11) {
            if (score >= 19 && score < 25) {
                resultScore = 5;
            } else if (score >= 25 && score < 33) {
                resultScore = 10;
            } else if (score >= 33 && score < 39) {
                resultScore = 25;
            } else if (score >= 39 && score < 43) {
                resultScore = 50;
            } else if (score >= 43 && score < 50) {
                resultScore = 75;
            } else if (score >= 50 && score < 52) {
                resultScore = 90;
            } else if (score >= 52) {
                resultScore = 95;
            }

        } else if (age == 11.5) {
            if (score >= 19 && score < 25) {
                resultScore = 5;
            } else if (score >= 25 && score < 35) {
                resultScore = 10;
            } else if (score >= 35 && score < 42) {
                resultScore = 25;
            } else if (score >= 42 && score < 45) {
                resultScore = 50;
            } else if (score >= 45 && score < 50) {
                resultScore = 75;
            } else if (score >= 50 && score < 53) {
                resultScore = 90;
            } else if (score >= 53) {
                resultScore = 95;
            }

        } else if (age == 12) {
            if (score >= 21 && score < 27) {
                resultScore = 5;
            } else if (score >= 27 && score < 37) {
                resultScore = 10;
            } else if (score >= 37 && score < 42) {
                resultScore = 25;
            } else if (score >= 42 && score < 46) {
                resultScore = 50;
            } else if (score >= 46 && score < 50) {
                resultScore = 75;
            } else if (score >= 50 && score < 53) {
                resultScore = 90;
            } else if (score >= 53) {
                resultScore = 95;
            }

        } else if (age == 12.5) {
            if (score >= 28 && score < 33) {
                resultScore = 5;
            } else if (score >= 33 && score < 40) {
                resultScore = 10;
            } else if (score >= 40 && score < 45) {
                resultScore = 25;
            } else if (score >= 45 && score < 50) {
                resultScore = 50;
            } else if (score >= 50 && score < 52) {
                resultScore = 75;
            } else if (score >= 52 && score < 53) {
                resultScore = 90;
            } else if (score >= 53) {
                resultScore = 95;
            }

        } else if (age == 13) {
            if (score >= 30 && score < 35) {
                resultScore = 5;
            } else if (score >= 35 && score < 40) {
                resultScore = 10;
            } else if (score >= 40 && score < 45) {
                resultScore = 25;
            } else if (score >= 45 && score < 50) {
                resultScore = 50;
            } else if (score >= 50 && score < 52) {
                resultScore = 75;
            } else if (score >= 52 && score < 53) {
                resultScore = 90;
            } else if (score >= 53) {
                resultScore = 95;
            }

        } else if (age == 13.5) {
            if (score >= 32 && score < 35) {
                resultScore = 5;
            } else if (score >= 35 && score < 42) {
                resultScore = 10;
            } else if (score >= 42 && score < 46) {
                resultScore = 25;
            } else if (score >= 46 && score < 50) {
                resultScore = 50;
            } else if (score >= 50 && score < 52) {
                resultScore = 75;
            } else if (score >= 52 && score < 54) {
                resultScore = 90;
            } else if (score >= 54) {
                resultScore = 95;
            }

        } else if (age == 14) {
            if (score >= 34 && score < 36) {
                resultScore = 5;
            } else if (score >= 36 && score < 43) {
                resultScore = 10;
            } else if (score >= 43 && score < 48) {
                resultScore = 25;
            } else if (score >= 48 && score < 50) {
                resultScore = 50;
            } else if (score >= 50 && score < 52) {
                resultScore = 75;
            } else if (score >= 52 && score < 55) {
                resultScore = 90;
            } else if (score >= 55) {
                resultScore = 95;
            }

        } else if (age == 14.5) {
            if (score >= 34 && score < 36) {
                resultScore = 5;
            } else if (score >= 36 && score < 43) {
                resultScore = 10;
            } else if (score >= 43 && score < 48) {
                resultScore = 25;
            } else if (score >= 48 && score < 51) {
                resultScore = 50;
            } else if (score >= 51 && score < 53) {
                resultScore = 75;
            } else if (score >= 53 && score < 55) {
                resultScore = 90;
            } else if (score >= 55) {
                resultScore = 95;
            }

        } else if (age == 15) {
            if (score >= 34 && score < 36) {
                resultScore = 5;
            } else if (score >= 36 && score < 43) {
                resultScore = 10;
            } else if (score >= 43 && score < 48) {
                resultScore = 25;
            } else if (score >= 48 && score < 51) {
                resultScore = 50;
            } else if (score >= 51 && score < 54) {
                resultScore = 75;
            } else if (score >= 54 && score < 57) {
                resultScore = 90;
            } else if (score >= 57) {
                resultScore = 95;
            }

        } else if (age == 15.5) {
            if (score >= 34 && score < 41) {
                resultScore = 5;
            } else if (score >= 41 && score < 43) {
                resultScore = 10;
            } else if (score >= 43 && score < 49) {
                resultScore = 25;
            } else if (score >= 49 && score < 52) {
                resultScore = 50;
            } else if (score >= 52 && score < 55) {
                resultScore = 75;
            } else if (score >= 55 && score < 57) {
                resultScore = 90;
            } else if (score >= 57) {
                resultScore = 95;
            }

        } else if (age == 16) {
            if (score >= 36 && score < 41) {
                resultScore = 5;
            } else if (score >= 41 && score < 44) {
                resultScore = 10;
            } else if (score >= 44 && score < 49) {
                resultScore = 25;
            } else if (score >= 49 && score < 53) {
                resultScore = 50;
            } else if (score >= 53 && score < 56) {
                resultScore = 75;
            } else if (score >= 56 && score < 57) {
                resultScore = 90;
            } else if (score >= 57) {
                resultScore = 95;
            }

        } else if (age == 16.5) {
            if (score >= 37 && score < 41) {
                resultScore = 5;
            } else if (score >= 41 && score < 45) {
                resultScore = 10;
            } else if (score >= 45 && score < 49) {
                resultScore = 25;
            } else if (score >= 49 && score < 53) {
                resultScore = 50;
            } else if (score >= 53 && score < 56) {
                resultScore = 75;
            } else if (score >= 56 && score < 57) {
                resultScore = 90;
            } else if (score >= 57) {
                resultScore = 95;
            }

        } else if (age == 17) {
            if (score >= 37 && score < 40) {
                resultScore = 5;
            } else if (score >= 40 && score < 47) {
                resultScore = 10;
            } else if (score >= 47 && score < 52) {
                resultScore = 25;
            } else if (score >= 52 && score < 55) {
                resultScore = 50;
            } else if (score >= 55 && score < 57) {
                resultScore = 75;
            } else if (score >= 57 && score < 58) {
                resultScore = 90;
            } else if (score >= 58) {
                resultScore = 95;
            }

        } else if (age > 17 && age <= 24.5) {//20
            if (score >= 33 && score < 38) {
                resultScore = 5;
            } else if (score >= 38 && score < 44) {
                resultScore = 10;
            } else if (score >= 44 && score < 50) {
                resultScore = 25;
            } else if (score >= 50 && score < 54) {
                resultScore = 50;
            } else if (score >= 54 && score < 56) {
                resultScore = 75;
            } else if (score >= 56 && score < 57) {
                resultScore = 90;
            } else if (score >= 57) {
                resultScore = 95;
            }

        } else if (age >= 25 && age <= 34.5) {//30
            if (score >= 28 && score < 37) {
                resultScore = 5;
            } else if (score >= 37 && score < 43) {
                resultScore = 10;
            } else if (score >= 43 && score < 48) {
                resultScore = 25;
            } else if (score >= 48 && score < 52) {
                resultScore = 50;
            } else if (score >= 52 && score < 55) {
                resultScore = 75;
            } else if (score >= 55 && score < 57) {
                resultScore = 90;
            } else if (score >= 57) {
                resultScore = 95;
            }

        } else if (age >= 35 && age <= 44.5) {//40
            if (score >= 28 && score < 31) {
                resultScore = 5;
            } else if (score >= 31 && score < 41) {
                resultScore = 10;
            } else if (score >= 41 && score < 47) {
                resultScore = 25;
            } else if (score >= 47 && score < 50) {
                resultScore = 50;
            } else if (score >= 50 && score < 54) {
                resultScore = 75;
            } else if (score >= 54 && score < 57) {
                resultScore = 90;
            } else if (score >= 57) {
                resultScore = 95;
            }

        } else if (age >= 45 && age <= 54.5) {//50
            if (score >= 21 && score < 24) {
                resultScore = 5;
            } else if (score >= 24 && score < 34) {
                resultScore = 10;
            } else if (score >= 34 && score < 42) {
                resultScore = 25;
            } else if (score >= 42 && score < 48) {
                resultScore = 50;
            } else if (score >= 48 && score < 52) {
                resultScore = 75;
            } else if (score >= 52 && score < 54) {
                resultScore = 90;
            } else if (score >= 54) {
                resultScore = 95;
            }

        } else if (age >= 55 && age <= 64.5) {//60
            if (score >= 19 && score < 22) {
                resultScore = 5;
            } else if (score >= 22 && score < 30) {
                resultScore = 10;
            } else if (score >= 30 && score < 37) {
                resultScore = 25;
            } else if (score >= 37 && score < 46) {
                resultScore = 50;
            } else if (score >= 46 && score < 52) {
                resultScore = 75;
            } else if (score >= 52 && score < 54) {
                resultScore = 90;
            } else if (score >= 54) {
                resultScore = 95;
            }

        } else {//70
            if (score >= 17 && score < 18) {
                resultScore = 5;
            } else if (score >= 18 && score < 26) {
                resultScore = 10;
            } else if (score >= 26 && score < 33) {
                resultScore = 25;
            } else if (score >= 33 && score < 44) {
                resultScore = 50;
            } else if (score >= 44 && score < 49) {
                resultScore = 75;
            } else if (score >= 49 && score < 52) {
                resultScore = 90;
            } else if (score >= 52) {
                resultScore = 95;
            }
        }

        return resultScore;
    }

}
